prompt_toolkit: Interactive command lines for Python
====================================================

Description
-----------

Library for building powerful interactive command lines in Python

https://pypi.python.org/pypi/prompt_toolkit
